@@ -4,6 +4,10 @@ import subprocess
 import sys
 
 from ruamel.yaml import YAML
+from types import SimpleNamespace
+
+from proxy2vpn.cli import system_init
+from proxy2vpn.server_manager import ServerManager
 
 
 def _run_proxy2vpn(args, cwd):
@@ -28,6 +32,7 @@ def test_init_creates_compose(tmp_path):
     data = yaml.load(compose.read_text())
     assert data["services"] == {}
     assert "proxy2vpn_network" in data["networks"]
+    assert "version" not in data
 
 
 def test_init_requires_force(tmp_path):
@@ -39,3 +44,15 @@ def test_init_requires_force(tmp_path):
 
     result = _run_proxy2vpn(["system", "init", "--force"], tmp_path)
     assert result.returncode == 0
+
+
+def test_system_init_updates_servers(tmp_path, monkeypatch):
+    called = {}
+
+    async def fake_update(self, verify=True):
+        called["update"] = verify
+
+    monkeypatch.setattr(ServerManager, "fetch_server_list_async", fake_update)
+    ctx = SimpleNamespace(obj={"compose_file": tmp_path / "compose.yml"})
+    system_init(ctx, force=True)
+    assert called["update"] is True
